==> db4o-5.0-mono.tar.gz: db4o-5.0/src/core/src/j4o/io/InputStream.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using System.IO;

namespace j4o.io {

	public class InputStream : StreamAdaptor {

		public InputStream(Stream stream) : base(stream) {
		}

		public int available() {
			return (int)(_stream.Length - _stream.Position);
		}

		public int read() {
			return _stream.ReadByte();
		}

        public int read(byte[] bytes){
            int read = _stream.Read(bytes, 0, bytes.Length);
            return (0 == read) ? -1 : read;
        }

		public int read(byte[] bytes, int offset, int length) {
            int read = _stream.Read(bytes, offset, length);
            return (0 == read) ? -1 : read;
		}
	}
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/core/src/j4o/io/InputStream.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using System.IO;

namespace j4o.io {

	public class InputStream : StreamAdaptor {

		public InputStream(Stream stream) : base(stream) {
		}

		public int Available() {
			return (int)(_stream.Length - _stream.Position);
		}

		public int Read() {
			return _stream.ReadByte();
		}

        public int Read(byte[] bytes){
            int read = _stream.Read(bytes, 0, bytes.Length);
            return (0 == read) ? -1 : read;
        }

		public int Read(byte[] bytes, int offset, int length) {
            int read = _stream.Read(bytes, offset, length);
            return (0 == read) ? -1 : read;
		}
	}
}
